@@ -3,10 +3,12 @@ from .edge_transformer import EdgeTransformer
 from .node_transformer import NodeTransformer
 from .graph_transformer import GraphTransformer
 from .corpus_transformer import CorpusTransformer
+from .link_prediction_transformer import LinkPredictionTransformer
 
 __all__ = [
     "EdgeTransformer",
     "NodeTransformer",
     "GraphTransformer",
-    "CorpusTransformer"
+    "CorpusTransformer",
+    "LinkPredictionTransformer"
 ]
